Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(32)

Unified Diff: device/bluetooth/bluetooth_adapter_mac.h

Issue 2242833002: Bluetooth: mac: add connected BLE devices at startup Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Device: bluetooth: use untyped containers Created 4 years, 3 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « no previous file | device/bluetooth/bluetooth_adapter_mac.mm » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: device/bluetooth/bluetooth_adapter_mac.h
diff --git a/device/bluetooth/bluetooth_adapter_mac.h b/device/bluetooth/bluetooth_adapter_mac.h
index d0ef4c3972d72ba699eeece533e111fd9e7febb4..ff88f6e04ef82e57440837348e31eefd15412777 100644
--- a/device/bluetooth/bluetooth_adapter_mac.h
+++ b/device/bluetooth/bluetooth_adapter_mac.h
@@ -49,7 +49,8 @@ class DEVICE_BLUETOOTH_EXPORT BluetoothAdapterMac
static base::WeakPtr<BluetoothAdapterMac> CreateAdapterForTest(
std::string name,
std::string address,
- scoped_refptr<base::SequencedTaskRunner> ui_task_runner);
+ scoped_refptr<base::SequencedTaskRunner> ui_task_runner,
+ CBCentralManager* central_manager = nil);
// Converts CBUUID into BluetoothUUID
static BluetoothUUID BluetoothUUIDWithCBUUID(CBUUID* UUID);
@@ -177,9 +178,13 @@ class DEVICE_BLUETOOTH_EXPORT BluetoothAdapterMac
// Updates |devices_| when there is a change to the CBCentralManager's state.
void LowEnergyCentralManagerUpdatedState();
- // Updates |devices_| to include the currently paired devices and notifies
- // observers.
- void AddPairedDevices();
+ // Updates |devices_| to include the currently paired Bluetooth Classic
+ // devices and notifies observers.
+ void AddPairedClassicDevices();
+
+ // Updates |devices_| to include the currently connected Bluetooth Low Energy
+ // devices and notifies observers.
+ void AddConnectedLowEnergyDevices();
// Returns the BLE device associated with the CoreBluetooth peripheral.
BluetoothLowEnergyDeviceMac* GetBluetoothLowEnergyDeviceMac(
« no previous file with comments | « no previous file | device/bluetooth/bluetooth_adapter_mac.mm » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698